@@ -1,12 +1,10 @@
 package MooseX::Types::Base;
-our $VERSION = "0.24";
+BEGIN {
+  $MooseX::Types::Base::VERSION = '0.26';
+}
 use Moose;
 
-=head1 NAME
-
-MooseX::Types::Base - Type library base class
-
-=cut
+# ABSTRACT: Type library base class
 
 use Carp::Clan                      qw( ^MooseX::Types );
 use MooseX::Types::Util             qw( filter_tags );
@@ -15,26 +13,10 @@ use Moose::Util::TypeConstraints;
 
 use namespace::clean -except => [qw( meta )];
 
-=head1 DESCRIPTION
-
-You normally won't need to interact with this class by yourself. It is
-merely a collection of functionality that type libraries need to 
-interact with moose and the rest of the L<MooseX::Types> module.
-
-=cut
 
 my $UndefMsg = q{Unable to find type '%s' in library '%s'};
 
-=head1 METHODS
 
-=cut
-
-=head2 import
-
-Provides the import mechanism for your library. See 
-L<MooseX::Types/"LIBRARY USAGE"> for syntax details on this.
-
-=cut
 
 sub import {
     my ($class, @args) = @_;
@@ -115,11 +97,6 @@ sub import {
     return $class->$exporter(@new_args);
 }
 
-=head2 get_type
-
-This returns a type from the library's store by its name.
-
-=cut
 
 sub get_type {
     my ($class, $type) = @_;
@@ -132,11 +109,6 @@ sub get_type {
     return $class->type_storage->{ $type };
 }
 
-=head2 type_names
-
-Returns a list of all known types by their name.
-
-=cut
 
 sub type_names {
     my ($class) = @_;
@@ -145,11 +117,6 @@ sub type_names {
     return keys %{ $class->type_storage };
 }
 
-=head2 add_type
-
-Adds a new type to the library.
-
-=cut
 
 sub add_type {
     my ($class, $type) = @_;
@@ -158,12 +125,6 @@ sub add_type {
     $class->type_storage->{ $type } = "${class}::${type}";
 }
 
-=head2 has_type
-
-Returns true or false depending on if this library knows a type by that
-name.
-
-=cut
 
 sub has_type {
     my ($class, $type) = @_;
@@ -172,13 +133,6 @@ sub has_type {
     return ! ! $class->type_storage->{ $type };
 }
 
-=head2 type_storage
-
-Returns the library's type storage hash reference. You shouldn't use this
-method directly unless you know what you are doing. It is not an internal
-method because overriding it makes virtual libraries very easy.
-
-=cut
 
 sub type_storage {
     my ($class) = @_;
@@ -189,11 +143,6 @@ sub type_storage {
     }
 }
 
-=head2 registered_class_types
-
-Returns the class types registered within this library. Don't use directly.
-
-=cut
 
 sub registered_class_types {
     my ($class) = @_;
@@ -204,11 +153,6 @@ sub registered_class_types {
     }
 }
 
-=head2 register_class_type
-
-Register a C<class_type> for use in this library by class name.
-
-=cut
 
 sub register_class_type {
     my ($class, $type) = @_;
@@ -219,11 +163,6 @@ sub register_class_type {
     $class->registered_class_types->{$type->class} = $type;
 }
 
-=head2 get_registered_class_type
-
-Get a C<class_type> registered in this library by name.
-
-=cut
 
 sub get_registered_class_type {
     my ($class, $name) = @_;
@@ -231,11 +170,6 @@ sub get_registered_class_type {
     $class->registered_class_types->{$name};
 }
 
-=head2 registered_role_types
-
-Returns the role types registered within this library. Don't use directly.
-
-=cut
 
 sub registered_role_types {
     my ($class) = @_;
@@ -246,11 +180,6 @@ sub registered_role_types {
     }
 }
 
-=head2 register_role_type
-
-Register a C<role_type> for use in this library by role name.
-
-=cut
 
 sub register_role_type {
     my ($class, $type) = @_;
@@ -261,11 +190,6 @@ sub register_role_type {
     $class->registered_role_types->{$type->role} = $type;
 }
 
-=head2 get_registered_role_type
-
-Get a C<role_type> registered in this library by role name.
-
-=cut
 
 sub get_registered_role_type {
     my ($class, $name) = @_;
@@ -273,19 +197,99 @@ sub get_registered_role_type {
     $class->registered_role_types->{$name};
 }
 
+
+1;
+
+__END__
+=pod
+
+=head1 NAME
+
+MooseX::Types::Base - Type library base class
+
+=head1 VERSION
+
+version 0.26
+
+=head1 DESCRIPTION
+
+You normally won't need to interact with this class by yourself. It is
+merely a collection of functionality that type libraries need to 
+interact with moose and the rest of the L<MooseX::Types> module.
+
+=head1 METHODS
+
+=head2 import
+
+Provides the import mechanism for your library. See 
+L<MooseX::Types/"LIBRARY USAGE"> for syntax details on this.
+
+=head2 get_type
+
+This returns a type from the library's store by its name.
+
+=head2 type_names
+
+Returns a list of all known types by their name.
+
+=head2 add_type
+
+Adds a new type to the library.
+
+=head2 has_type
+
+Returns true or false depending on if this library knows a type by that
+name.
+
+=head2 type_storage
+
+Returns the library's type storage hash reference. You shouldn't use this
+method directly unless you know what you are doing. It is not an internal
+method because overriding it makes virtual libraries very easy.
+
+=head2 registered_class_types
+
+Returns the class types registered within this library. Don't use directly.
+
+=head2 register_class_type
+
+Register a C<class_type> for use in this library by class name.
+
+=head2 get_registered_class_type
+
+Get a C<class_type> registered in this library by name.
+
+=head2 registered_role_types
+
+Returns the role types registered within this library. Don't use directly.
+
+=head2 register_role_type
+
+Register a C<role_type> for use in this library by role name.
+
+=head2 get_registered_role_type
+
+Get a C<role_type> registered in this library by role name.
+
 =head1 SEE ALSO
 
 L<MooseX::Types::Moose>
 
-=head1 AUTHOR
-
-See L<MooseX::Types/AUTHOR>.
-
 =head1 LICENSE
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as perl itself.
 
+=head1 AUTHOR
+
+Robert "phaylon" Sedlacek <rs@474.at>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Robert "phaylon" Sedlacek.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-1;
