@@ -1,11 +1,9 @@
 package MooseX::Types::Moose;
-our $VERSION = "0.24";
+BEGIN {
+  $MooseX::Types::Moose::VERSION = '0.26';
+}
 
-=head1 NAME
-
-MooseX::Types::Moose - Types shipped with L<Moose>
-
-=cut
+# ABSTRACT: Type exports that match the types shipped with L<Moose>
 
 use warnings;
 use strict;
@@ -15,6 +13,30 @@ use Moose::Util::TypeConstraints ();
 
 use namespace::clean -except => [qw( meta )];
 
+
+# all available builtin types as short and long name
+my %BuiltIn_Storage 
+  = map { ($_) x 2 } 
+    Moose::Util::TypeConstraints->list_all_builtin_type_constraints;
+
+
+# use prepopulated builtin hash as type storage
+sub type_storage { \%BuiltIn_Storage }
+
+
+1;
+
+__END__
+=pod
+
+=head1 NAME
+
+MooseX::Types::Moose - Type exports that match the types shipped with L<Moose>
+
+=head1 VERSION
+
+version 0.26
+
 =head1 SYNOPSIS
 
   package Foo;
@@ -45,13 +67,6 @@ This package contains a virtual library for L<MooseX::Types> that
 is able to export all types known to L<Moose>. See L<MooseX::Types>
 for general usage information.
 
-=cut
-
-# all available builtin types as short and long name
-my %BuiltIn_Storage 
-  = map { ($_) x 2 } 
-    Moose::Util::TypeConstraints->list_all_builtin_type_constraints;
-
 =head1 METHODS
 
 =head2 type_storage
@@ -59,26 +74,27 @@ my %BuiltIn_Storage
 Overrides L<MooseX::Types::Base>' C<type_storage> to provide a hash
 reference containing all built-in L<Moose> types.
 
-=cut
-
-# use prepopulated builtin hash as type storage
-sub type_storage { \%BuiltIn_Storage }
-
 =head1 SEE ALSO
 
 L<MooseX::Types::Moose>,
 L<Moose>, 
 L<Moose::Util::TypeConstraints>
 
-=head1 AUTHOR
-
-See L<MooseX::Types/AUTHOR>.
-
 =head1 LICENSE
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as perl itself.
 
+=head1 AUTHOR
+
+Robert "phaylon" Sedlacek <rs@474.at>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Robert "phaylon" Sedlacek.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
-1;
